@@ -156,7 +156,7 @@ kwargs_bilq = (:c, :transfer_to_bicg, :M, :N, :ldiv, :atol, :rtol, :itmax, :time
     s = NisI ? p : workspace.s
 
     if warm_start
-      mul!(r₀, A, Δx)
+      kmul!(r₀, A, Δx)
       kaxpby!(n, one(FC), b, -one(FC), r₀)
     end
     if !MisI
@@ -233,12 +233,12 @@ kwargs_bilq = (:c, :transfer_to_bicg, :M, :N, :ldiv, :atol, :rtol, :itmax, :time
 
       # Forms vₖ₊₁ : q ← MANvₖ
       NisI || mulorldiv!(Nvₖ, N, vₖ, ldiv)
-      mul!(t, A, Nvₖ)
+      kmul!(t, A, Nvₖ)
       MisI || mulorldiv!(q, M, t, ldiv)
 
       # Forms uₖ₊₁ : p ← NᴴAᴴMᴴuₖ
       MisI || mulorldiv!(Mᴴuₖ, Mᴴ, uₖ, ldiv)
-      mul!(s, Aᴴ, Mᴴuₖ)
+      kmul!(s, Aᴴ, Mᴴuₖ)
       NisI || mulorldiv!(p, Nᴴ, s, ldiv)
 
       kaxpy!(n, -γₖ, vₖ₋₁, q)  # q ← q - γₖ * vₖ₋₁
