@@ -33,19 +33,21 @@ Given a matrix `A` of dimension m × n, TriCG solves the Hermitian linear system
     [ τE    A ] [ x ] = [ b ]
     [  Aᴴ  νF ] [ y ]   [ c ],
 
-of size (n+m) × (n+m) where τ and ν are real numbers, E = M⁻¹ ≻ 0 and F = N⁻¹ ≻ 0.
+of size (n+m) × (n+m) where `τ` and `ν` are real numbers, `E` = `M⁻¹` ≻ 0 and `F` = `N⁻¹` ≻ 0.
 TriCG could breakdown if `τ = 0` or `ν = 0`.
 It's recommended to use TriMR in these cases.
 
-By default, TriCG solves Hermitian and quasi-definite linear systems with τ = 1 and ν = -1.
+By default, TriCG solves Hermitian and quasi-definite linear systems with `τ = 1` and `ν = -1`.
 
 TriCG is based on the preconditioned orthogonal tridiagonalization process
 and its relation with the preconditioned block-Lanczos process.
 
+The matrix
+
     [ M   0 ]
     [ 0   N ]
 
-indicates the weighted norm in which residuals are measured.
+indicates the weighted norm in which residuals are measured, here denoted `‖·‖`.
 It's the Euclidean norm when `M` and `N` are identity operators.
 
 TriCG stops when `itmax` iterations are reached or when `‖rₖ‖ ≤ atol + ‖r₀‖ * rtol`.
@@ -68,6 +70,8 @@ For an in-place variant that reuses memory across solves, see [`tricg!`](@ref).
 * `x0`: a vector of length `m` that represents an initial guess of the solution `x`;
 * `y0`: a vector of length `n` that represents an initial guess of the solution `y`.
 
+Warm-starting is supported only when `M` and `N` are either `I` or the corresponding coefficient (`τ` or `ν`) is zero.
+
 #### Keyword arguments
 
 * `M`: linear operator that models a Hermitian positive-definite matrix of size `m` used for centered preconditioning of the partitioned system;
@@ -211,10 +215,10 @@ kwargs_tricg = (:M, :N, :ldiv, :spd, :snd, :flip, :τ, :ν, :atol, :rtol, :itmax
     # [ τI    A ] [ xₖ ] = [ b -  τΔx - AΔy ] = [ b₀ ]
     # [  Aᴴ  νI ] [ yₖ ]   [ c - AᴴΔx - νΔy ]   [ c₀ ]
     if warm_start
-      mul!(b₀, A, Δy)
+      kmul!(b₀, A, Δy)
       (τ ≠ 0) && kaxpy!(m, τ, Δx, b₀)
       kaxpby!(m, one(FC), b, -one(FC), b₀)
-      mul!(c₀, Aᴴ, Δx)
+      kmul!(c₀, Aᴴ, Δx)
       (ν ≠ 0) && kaxpy!(n, ν, Δy, c₀)
       kaxpby!(n, one(FC), c, -one(FC), c₀)
     end
@@ -283,8 +287,8 @@ kwargs_tricg = (:M, :N, :ldiv, :spd, :snd, :flip, :τ, :ν, :atol, :rtol, :itmax
       # AUₖ  = EVₖTₖ    + βₖ₊₁Evₖ₊₁(eₖ)ᵀ = EVₖ₊₁Tₖ₊₁.ₖ
       # AᴴVₖ = FUₖ(Tₖ)ᴴ + γₖ₊₁Fuₖ₊₁(eₖ)ᵀ = FUₖ₊₁(Tₖ.ₖ₊₁)ᴴ
 
-      mul!(q, A , uₖ)  # Forms Evₖ₊₁ : q ← Auₖ
-      mul!(p, Aᴴ, vₖ)  # Forms Fuₖ₊₁ : p ← Aᴴvₖ
+      kmul!(q, A , uₖ)  # Forms Evₖ₊₁ : q ← Auₖ
+      kmul!(p, Aᴴ, vₖ)  # Forms Fuₖ₊₁ : p ← Aᴴvₖ
 
       if iter ≥ 2
         kaxpy!(m, -γₖ, M⁻¹vₖ₋₁, q)  # q ← q - γₖ * M⁻¹vₖ₋₁
