@@ -33,18 +33,20 @@ Given a matrix `A` of dimension m × n, TriMR solves the symmetric linear system
     [ τE    A ] [ x ] = [ b ]
     [  Aᴴ  νF ] [ y ]   [ c ],
 
-of size (n+m) × (n+m) where τ and ν are real numbers, E = M⁻¹ ≻ 0, F = N⁻¹ ≻ 0.
+of size (n+m) × (n+m) where `τ` and `ν` are real numbers, `E` = `M⁻¹` ≻ 0, `F` = `N⁻¹` ≻ 0.
 TriMR handles saddle-point systems (`τ = 0` or `ν = 0`) and adjoint systems (`τ = 0` and `ν = 0`) without any risk of breakdown.
 
-By default, TriMR solves symmetric and quasi-definite linear systems with τ = 1 and ν = -1.
+By default, TriMR solves symmetric and quasi-definite linear systems with `τ` = 1 and `ν` = -1.
 
 TriMR is based on the preconditioned orthogonal tridiagonalization process
 and its relation with the preconditioned block-Lanczos process.
 
+The matrix
+
     [ M   0 ]
     [ 0   N ]
 
-indicates the weighted norm in which residuals are measured.
+indicates the weighted norm in which residuals are measured, here denoted `‖·‖`.
 It's the Euclidean norm when `M` and `N` are identity operators.
 
 TriMR stops when `itmax` iterations are reached or when `‖rₖ‖ ≤ atol + ‖r₀‖ * rtol`.
@@ -67,6 +69,8 @@ For an in-place variant that reuses memory across solves, see [`trimr!`](@ref).
 * `x0`: a vector of length `m` that represents an initial guess of the solution `x`;
 * `y0`: a vector of length `n` that represents an initial guess of the solution `y`.
 
+Warm-starting is supported only when `M` and `N` are either `I` or the corresponding coefficient (`τ` or `ν`) is zero.
+
 #### Keyword arguments
 
 * `M`: linear operator that models a Hermitian positive-definite matrix of size `m` used for centered preconditioning of the partitioned system;
@@ -217,10 +221,10 @@ kwargs_trimr = (:M, :N, :ldiv, :spd, :snd, :flip, :sp, :τ, :ν, :atol, :rtol, :
     # [ τI    A ] [ xₖ ] = [ b -  τΔx - AΔy ] = [ b₀ ]
     # [  Aᴴ  νI ] [ yₖ ]   [ c - AᴴΔx - νΔy ]   [ c₀ ]
     if warm_start
-      mul!(b₀, A, Δy)
+      kmul!(b₀, A, Δy)
       (τ ≠ 0) && kaxpy!(m, τ, Δx, b₀)
       kaxpby!(m, one(FC), b, -one(FC), b₀)
-      mul!(c₀, Aᴴ, Δx)
+      kmul!(c₀, Aᴴ, Δx)
       (ν ≠ 0) && kaxpy!(n, ν, Δy, c₀)
       kaxpby!(n, one(FC), c, -one(FC), c₀)
     end
@@ -297,8 +301,8 @@ kwargs_trimr = (:M, :N, :ldiv, :spd, :snd, :flip, :sp, :τ, :ν, :atol, :rtol, :
       # AUₖ  = EVₖTₖ    + βₖ₊₁Evₖ₊₁(eₖ)ᵀ = EVₖ₊₁Tₖ₊₁.ₖ
       # AᴴVₖ = FUₖ(Tₖ)ᴴ + γₖ₊₁Fuₖ₊₁(eₖ)ᵀ = FUₖ₊₁(Tₖ.ₖ₊₁)ᴴ
 
-      mul!(q, A , uₖ)  # Forms Evₖ₊₁ : q ← Auₖ
-      mul!(p, Aᴴ, vₖ)  # Forms Fuₖ₊₁ : p ← Aᴴvₖ
+      kmul!(q, A , uₖ)  # Forms Evₖ₊₁ : q ← Auₖ
+      kmul!(p, Aᴴ, vₖ)  # Forms Fuₖ₊₁ : p ← Aᴴvₖ
 
       if iter ≥ 2
         kaxpy!(m, -γₖ, M⁻¹vₖ₋₁, q)  # q ← q - γₖ * M⁻¹vₖ₋₁
